#version 400 core

uniform vec3 lightPos;
uniform vec3 viewPoint;
uniform sampler2D diffuseMap;
uniform sampler2DShadow shadowMap;

in vec2 gUV;
in vec3 gVertex;
in vec4 gSMVertex;
smooth in vec3 gNormal;
out vec4[2] finalColor;

const float ambient = 0.3;
const float diffuse = 0.8;
const float shininess = 2;

void main()
{
	vec3 lightVec = normalize(lightPos - gVertex);
	vec3 viewVec = normalize(viewPoint - gVertex);

	//vec4 color = gColor;
	vec4 color = texture(diffuseMap, gUV);
	
	//Ambient
	vec4 Ia = color * ambient;
	
	//In Shadow?
	float shadow = textureProj(shadowMap, gSMVertex);

	//Diffuse
	vec4 Id = color * diffuse * max(dot(gNormal, lightVec),0.0f);

	//Specular
	vec4 spec = vec4(0.0f,0.0f,0.0f,1.0f);
	vec3 reflection = normalize(reflect(lightVec, gNormal));
	vec4 Is = color * spec * max(pow(dot(reflection, -viewVec), shininess),0.0f);
	
	//Hard shadow
	/* Id*=shadow;
	Is*=shadow; */

	finalColor[0]=clamp(Ia + Id + (Is*2),0.0f,1.0f);
	finalColor[0][3] = 1.0f;
	finalColor[1]=vec4(vec3(1.0f,1.0f,1.0f) * (1-shadow),1.0f);
}