#version 400 core

//Material
uniform vec4 diffuse;
uniform vec4 specular;
uniform vec4 ambient;
uniform float shininess;
uniform sampler2D textureMap;
uniform bool hasTexture;
uniform sampler2DShadow shadowMap;
uniform bool transparent;

//Lighting
uniform vec3 lightPos;
uniform vec3 viewPoint;

in vec3 gNormal;
in vec2 gUV;
in vec4 gSMVertex;
smooth in vec3 point;
out vec4[2] out_color;

void main(void)
{	
	//In Shadow?
	float shadow = textureProj(shadowMap, gSMVertex);

	float texBlend = 1.0f;

	//Texture
	vec4 textColor = ambient;
	if(hasTexture)
	{
		textColor = texture(textureMap, gUV);

		if(!transparent)
		{
			texBlend = textColor[3];
			textColor[3] = 1.0f;
		}

		textColor = mix(diffuse,textColor, texBlend);
	}

	vec3 lightDir = lightPos - point;
	vec3 lightVec = normalize(lightDir);
	vec3 viewVec = normalize(point - viewPoint);

	//Ambient
	float Ia = 0.2f;

	//Diffuse
	float Id = max(dot(gNormal, lightVec),0.0f);

	//Specular
	vec3 reflektion = normalize(reflect(lightVec, gNormal));
	float Is = max(pow(dot(reflektion, viewVec), sqrt(shininess)),0.0f);

	/*Id *= shadow;
	Is *= shadow;*/

	//Equation
	if(!transparent)
	{
		out_color[0] = vec4(min((Ia + Id),1.0f) * textColor.rgb + (Is*2) * specular.rgb,1.0f);
		out_color[1] = vec4(vec3(1.0f,1.0f,1.0f) * (1-shadow),1.0f);
	}
	else
	{
		out_color[0] = vec4(textColor.rgb,textColor.a);
		out_color[1] = vec4(vec3(1.0f,1.0f,1.0f) * (1-shadow),textColor.a);
	}
}